@@ -41,7 +41,7 @@ KOrganizerPlugin::KOrganizerPlugin(KontactInterface::Core *core, const KPluginMe
 {
     setComponentName(QStringLiteral("korganizer"), i18n("KOrganizer"));
 
-    auto action = new QAction(QIcon::fromTheme(QStringLiteral("appointment-new")), i18nc("@action:inmenu", "New Event..."), this);
+    auto action = new QAction(QIcon::fromTheme(QStringLiteral("appointment-new")), i18nc("@action:inmenu", "New Event…"), this);
     actionCollection()->addAction(QStringLiteral("new_event"), action);
     actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_E));
     const QString str = i18nc("@info:status", "Create a new event");
