@@ -174,11 +174,10 @@ void MonthView::setDateRange(const QDateTime &start, const QDateTime &end, const
     mMonthView->setDateRange(start, end, preferredMonth);
 }
 
-void MonthView::setCalendar(const Akonadi::ETMCalendar::Ptr &cal)
+void MonthView::setModel(QAbstractItemModel *model)
 {
-    KOEventView::setCalendar(cal);
-    mPopup->setCalendar(cal);
-    mMonthView->setCalendar(cal);
+    KOEventView::setModel(model);
+    mMonthView->setModel(model);
 }
 
 void MonthView::setIncidenceChanger(Akonadi::IncidenceChanger *changer)
@@ -192,3 +191,14 @@ void MonthView::showDates(const QDate &start, const QDate &end, const QDate &pre
     Q_UNUSED(end)
     Q_UNUSED(preferredMonth)
 }
+
+void MonthView::calendarAdded(const Akonadi::CollectionCalendar::Ptr &calendar)
+{
+    mMonthView->addCalendar(calendar);
+}
+
+void MonthView::calendarRemoved(const Akonadi::CollectionCalendar::Ptr &calendar)
+{
+    mMonthView->removeCalendar(calendar);
+}
+#include "moc_monthview.cpp"
